<?php
 $tgl_time = date("Y-m-d h:i:sa");
 $sumber = ''
?>
<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
    <meta name="description" content="UMIBA, Universitas Mitra Bangsa, hadir dengan berbagai program pendidikan yang dirancang khusus untuk karyawan dan profesional. Dapatkan gelar S1 atau S2 Manajemen dengan biaya kuliah yang sangat terjangkau, hanya Rp 600.000 per bulan. Kuliah di UMIBA memungkinkan Anda belajar pada hari sabtu atau melalui kelas ekstensi, cocok untuk yang memiliki jadwal padat, dan tersedia kelas RPL dengan kuliah singkat, edunitas." />
    <meta name="keywords" content="Program Kuliah Malam UMIBA,Kuliah untuk Karyawan Jakarta,Kuliah S1 Manajemen Jakarta,Kuliah S2 Manajemen Jakarta,Universitas Murah Jakarta,Akreditasi Umiba, Kuliah Sambil Bekerja Jakarta,Kampus untuk Karyawan Jakarta Selatan,Program S1 Manajemen UMIBA Bintaro,Program S2 Manajemen UMIBA,Kampus Terjangkau Jakarta,Kampus Karyawan Jakarta,Sekolah Tinggi Manajemen Jakarta,Biaya Kuliah Terjangkau UMIBA,Kuliah Karyawan di Jakarta,Universitas Jakarta untuk Karyawan,Kuliah Sabtu UMIBA Bintaro,Universitas Murah untuk Karyawan Jakarta,Kampus UMIBA Pasar Minggu,Akreditasi UMIBA S1 Manajemen, stima immi, edunitas, rpl umiba, UT, universitas terbuka, S1 Hukum di Jakarta, S1 Komputer di Jakarta, S1 Aktuaria, S1 Sistem dan Teknologi informasi di jakarta selatan, kampus di pasar minggu, daftar online kuliah karyawan, cara kuliah di umiba, jadwal kuliah di umiba, biaya kuliah di umiba, cara daftar online di umiba, jurusan di umiba, lokasi kampus umiba" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

<!-- Required meta tags -->
    <title>Akreditasi Universitas Mitra Bangsa (Kelas Karyawan)</title>
    <meta property="og:title" content="Universitas Mitra Bangsa (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://umiba.online">
    <meta property="og:image" content="https://umiba.online/img/baner-UMIBA.png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Universitas Mitra Bangsa menawarkan fleksibilitas jadwal kuliah yang dirancang untuk memenuhi kebutuhan mahasiswa dengan berbagai latar belakang, termasuk profesional yang bekerja. Dengan pendekatan pembelajaran yang adaptif, universitas ini memungkinkan mahasiswa untuk mengatur waktu belajar tanpa mengorbankan komitmen lain. Dukungan dari dosen berpengalaman dan program studi yang relevan menjadikan Universitas Mitra Bangsa pilihan tepat bagi mereka yang mengutamakan pendidikan berkualitas dengan jadwal yang fleksibel.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Universitas Mitra Bangsa (Kelas Karyawan)">
    <meta name="twitter:description" content="Universitas Mitra Bangsa adalah institusi pendidikan tinggi yang berkomitmen untuk mencetak generasi unggul melalui program akademik berkualitas dan inovatif. Dengan pendekatan yang berfokus pada pengembangan keterampilan praktis dan integritas akademik, Universitas Mitra Bangsa menyediakan berbagai fakultas dan program studi yang relevan dengan kebutuhan industri dan masyarakat. Didukung oleh tenaga pengajar profesional dan fasilitas modern, universitas ini menjadi tempat yang ideal bagi mahasiswa untuk meraih prestasi dan membangun karier yang gemilang.">
    <meta name="twitter:domain" content="https://umiba.online">
    <meta name="twitter:image:src" content="https://umiba.online/img/baner-UMIBA.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="UMIBA | Kuliah Karyawan K2" />
	<title>STISIP BEKASI Kontak Pesan</title>
	<link rel="stylesheet" type="text/css" href="main.css">
<!--Favicon-->
		<link
			rel="shortcut icon"
			href="https://umiba.info/images/stisip.avif"
			type="image/x-icon"
		/>
		
		<link
			rel="icon"
			href="https://umiba.info/images/stisip.avif"
			type="image/x-icon"
		/>
	
	<!-- fontawesome.cdn for ICONS-->
	<link href="https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" rel="stylesheet" integrity="sha384-wvfXpqpZZVQGK6TAh5PVlGOfQNHSoD2xbE+QkPxCAFlNEevoEH3Sl0sibVcOQVnN" crossorigin="anonymous">

	<!--animatecss.cdn for ANIMATION-->
	<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/3.7.0/animate.css" />
	<style>
	    *{
	box-sizing: border-box;
}

body{
	background:#079f42;
	color: #485e74;
	line-height: 1.6;
	font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
	padding: 1em;
}

.container{
	max-width:1170px;
	margin-left: auto;
	margin-right: auto;
	padding: 1em;
}

ul{
	list-style: none;
	padding: 0;
}

.brand{
	text-align: center;
}
.brand span{
	color: #fff;
}

.wrapper{
	box-shadow: 0 0 20px 0 rgba(72,94,116,0.7);
} 

.wrapper >*{
	padding: 1em;
}

.company-info{
	background: #c9e6ff;
	text-align: center;
}

.company-info h3, .company-info ul{
	text-align: center;
	margin: 0 0 1rem 0;
}

.contact{
	background: #f9feff;
}

/* FORM CONTACTS
 MOBILE SIZE FIRST */

.contact form{
	display: grid;
	grid-template-columns: 1fr 1fr;
	grid-gap: 20px;
}

.contact form label{
	display: block;
}

.contact form p{
	margin:0; 
}

.contact form .full{
	grid-column: 1/3;
}

.contact form button, .contact form input, .contact form textarea{
	width: 100%;
	padding: 1em;
	border: 1px solid #c9e6ff;
}

.contact form button{
	background: #c9e6ff;
	border: 0;
	text-transform: uppercase;
}

.contact form button:hover, .contact form button:focus{
	background: #92bde7;
	color: #fff;
	outline:0;
	transition: background-color 0.5 s ease-out;
}

/* LARGE SCREENS */
@media(min-width:700px){
	.wrapper{
		display: grid;
		grid-template-columns: 1fr 2fr;
	}

	.wrapper>*{
		padding:2em;
	}

	.company-info h3, .company-info ul, .brand{
		text-align: left;
	}
}
	</style>

	<script src='https://www.google.com/recaptcha/api.js'></script>
</head>
<body>
	<div class='container'>
		<h1 class='brand'><span>Kontak</span> Kami</h1>

		<!--animated bounceInLeft class for selection what will be animated-->
		<div class='wrapper animated bounceInLeft'>
			<div class='company-info'>
				<h3>Universitas Mitra Bangsa</h3>
				<ul>

					<li><i class="fa fa-road"></i> Jl. Perdagangan No.54, RT.4/RW.7, Bintaro, Kec. Pesanggrahan, Kota Jakarta Selatan, Daerah Khusus Ibukota Jakarta 12330</li>
					<!--<li><i class="fa fa-road"></i> Jl. Perdagangan No.54, RT.4/RW.7, Bintaro, Kec. Pesanggrahan, Kota Jakarta Selatan, Daerah Khusus Ibukota Jakarta 12330</li>-->
					<!--<li><i class="fa fa-road"></i> Jl. Perdagangan No.54, RT.4/RW.7, Bintaro, Kec. Pesanggrahan, Kota Jakarta Selatan, Daerah Khusus Ibukota Jakarta 12330</li>-->
					<li><i class="fa fa-phone"></i> +62-817-6374-994</li>
					<li><i class="fa fa-globe"></i> umiba.info</li>
				</ul>
		</div>
		<div class='contact'>
			<h3>Kontak Pesan</h3>
			  <form action="proses-kontak.php" method="POST">
		
				<p>
					<label>Nama</label>
					<input type="text" name="nama"> 
				</p>

				<p>
					<label>Alamat Email</label>
					<input type="email" name="email"> 
				</p>

				<p>
					<label>Nomor Whatsapp/HP</label>
					<input type="number" name="no_hp"> 
				</p>
				<p class='full'>
					<label>Pesan</label>
					<textarea name="message" rows="5"></textarea> 
				</p>
				
					<p align="center" class="full g-recaptcha" data-sitekey="6LdCkmgeAAAAAHjTSuJy1QqCD6onhldKisK2zTKO" >
					<!--<div class="g-recaptcha" data-sitekey="6LdCkmgeAAAAAHjTSuJy1QqCD6onhldKisK2zTKO"></div>-->
				</p>
				<input
						type="hidden"
						name="tgl_pesan"
						value="<?= $tgl_time?>"
					
					
					/>

				<p class='full'>
				<button type="submit"  value="Daftar" name="daftar" class="submit-button" />Kirim Pesan</button>
				</p>
			</form>
		</div>
	</div>
	</div>
</body>
</html>