<?php
$servername = "localhost";
$database = "u645251767_umiba";
$username = "u645251767_umiba";
$password = "Umiba@2025";

// Koneksi
$conn = mysqli_connect($servername, $username, $password, $database);
if (!$conn) {
    die("Koneksi gagal: " . mysqli_connect_error());
}

// Ambil data biaya formulir
$formulirQuery = "SELECT * FROM setting WHERE jenis_set = 'biaya formulir'";
$formulirResult = mysqli_query($conn, $formulirQuery);
$formulir = [];
while ($row = mysqli_fetch_assoc($formulirResult)) {
    $key = strtoupper(trim($row['nama_set']));
    $formulir[$key] = $row['nilai_set'];
}

// Mapping kategori ke kode formulir
$kategori_to_formulir = [
    'Diploma' => 'D3',
    'Sarjana' => 'S1',
    'Magister' => 'S2'
];

// Ambil data biaya
$query = "SELECT * FROM biaya ORDER BY biaya_awal ASC";
$result = mysqli_query($conn, $query);
$groups = [];
while ($row = mysqli_fetch_assoc($result)) {
    $key = $row['biaya_awal'] . '-' . $row['biaya_spp'];
    if (!isset($groups[$key])) {
        $groups[$key] = [
            'kategori' => $row['kategori'],
            'biaya_awal' => $row['biaya_awal'],
            'biaya_spp' => $row['biaya_spp'],
            'jurusan' => []
        ];
    }
    $groups[$key]['jurusan'][] = $row['jurusan'];
}

// Ambil data nama kampus
$kampusQuery = "SELECT * FROM setting WHERE jenis_set = 'kampus'";
$kampusResult = mysqli_query($conn, $kampusQuery);
$kampusData = [];
while ($row = mysqli_fetch_assoc($kampusResult)) {
    $kampusData[$row['nama_set']] = $row['nilai_set'];
}
$namaKampus = $kampusData['nama kampus'] ?? 'Nama Kampus Tidak Ditemukan';

// Ambil data sosial media
$sosmedQuery = "SELECT * FROM setting WHERE jenis_set IN ('fb', 'ig')";
$sosmedResult = mysqli_query($conn, $sosmedQuery);
$sosmedLinks = [];
while ($row = mysqli_fetch_assoc($sosmedResult)) {
    $sosmedLinks[strtolower($row['nama_set'])] = $row['nilai_set'];
}

// Waktu
date_default_timezone_set('Asia/Jakarta');
$tgl_time = date("Y-m-d h:i:sa");
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="description" content="UMIBA, Universitas Mitra Bangsa, hadir dengan berbagai program pendidikan yang dirancang khusus untuk karyawan dan profesional. Dapatkan gelar S1 atau S2 Manajemen dengan biaya kuliah yang sangat terjangkau, hanya Rp 600.000 per bulan. Kuliah di UMIBA memungkinkan Anda belajar pada hari sabtu atau melalui kelas ekstensi, cocok untuk yang memiliki jadwal padat, dan tersedia kelas RPL dengan kuliah singkat, edunitas." />
    <meta name="keywords" content="Program Kuliah Malam UMIBA,Kuliah untuk Karyawan Jakarta,Kuliah S1 Manajemen Jakarta,Kuliah S2 Manajemen Jakarta,Universitas Murah Jakarta,Akreditasi Umiba, Kuliah Sambil Bekerja Jakarta,Kampus untuk Karyawan Jakarta Selatan,Program S1 Manajemen UMIBA Bintaro,Program S2 Manajemen UMIBA,Kampus Terjangkau Jakarta,Kampus Karyawan Jakarta,Sekolah Tinggi Manajemen Jakarta,Biaya Kuliah Terjangkau UMIBA,Kuliah Karyawan di Jakarta,Universitas Jakarta untuk Karyawan,Kuliah Sabtu UMIBA Bintaro,Universitas Murah untuk Karyawan Jakarta,Kampus UMIBA Pasar Minggu,Akreditasi UMIBA S1 Manajemen, stima immi, edunitas, rpl umiba, UT, universitas terbuka, S1 Hukum di Jakarta, S1 Komputer di Jakarta, S1 Aktuaria, S1 Sistem dan Teknologi informasi di jakarta selatan, kampus di pasar minggu, daftar online kuliah karyawan, cara kuliah di umiba, jadwal kuliah di umiba, biaya kuliah di umiba, cara daftar online di umiba, jurusan di umiba, lokasi kampus umiba" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    
    <title>Daftar Online Universitas Mitra Bangsa (Kelas Karyawan)</title>
    <meta property="og:title" content="Universitas Mitra Bangsa (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://umiba.online">
    <meta property="og:image" content="https://umiba.online/img/baner-UMIBA.png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Universitas Mitra Bangsa menawarkan fleksibilitas jadwal kuliah yang dirancang untuk memenuhi kebutuhan mahasiswa dengan berbagai latar belakang, termasuk profesional yang bekerja. Dengan pendekatan pembelajaran yang adaptif, universitas ini memungkinkan mahasiswa untuk mengatur waktu belajar tanpa mengorbankan komitmen lain. Dukungan dari dosen berpengalaman dan program studi yang relevan menjadikan Universitas Mitra Bangsa pilihan tepat bagi mereka yang mengutamakan pendidikan berkualitas dengan jadwal yang fleksibel.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Universitas Mitra Bangsa (Kelas Karyawan)">
    <meta name="twitter:description" content="Universitas Mitra Bangsa adalah institusi pendidikan tinggi yang berkomitmen untuk mencetak generasi unggul melalui program akademik berkualitas dan inovatif. Dengan pendekatan yang berfokus pada pengembangan keterampilan praktis dan integritas akademik, Universitas Mitra Bangsa menyediakan berbagai fakultas dan program studi yang relevan dengan kebutuhan industri dan masyarakat. Didukung oleh tenaga pengajar profesional dan fasilitas modern, universitas ini menjadi tempat yang ideal bagi mahasiswa untuk meraih prestasi dan membangun karier yang gemilang.">
    <meta name="twitter:domain" content="https://umiba.online">
    <meta name="twitter:image:src" content="https://umiba.online/img/baner-UMIBA.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="UMIBA | Kuliah Karyawan K2" />

    <link rel="apple-touch-icon" sizes="57x57" href="https://umiba.info//images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="https://umiba.info//images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="https://umiba.info//images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="https://umiba.info//images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="https://umiba.info//images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="https://umiba.info//images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="https://umiba.info//images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="https://umiba.info//images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="https://umiba.info//images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="https://umiba.info//images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="https://umiba.info//images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="https://umiba.info//images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="https://umiba.info//images/favicons/favicon-16x16.png">
    <link rel="manifest" href="https://umiba.info//images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="https://umiba.info//images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    <!--Inter UI font-->
    <link href="https://rsms.me/inter/inter-ui.css" rel="stylesheet" />

    <!--vendors styles-->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.css" />
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick-theme.min.css" />

    <!-- Bootstrap CSS / Color Scheme -->
    <link rel="stylesheet" href="css/default.css" id="theme-color" />
    <link rel="stylesheet" href="css/navbar.css" />
</head>

<body>
    <!-- navbar -->
    <div class="top-bar">
        <button class="top-bar__nav-toggle hamburger" id="top-nav-toggle">
            <span></span>
            <span></span>
            <span></span>
        </button>
        <a href="./" class="top-bar__brand"><?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?></a>
        <div class="top-bar__contact">
            <a href="https://api.whatsapp.com/send?phone=6289504586704&text=Hallo%20Admin%2C%20Saya%20Mau%20Bertanya%20%3F%20Sumber%20%3A%20WEB%20daftaronline.umiba.info" target="_blank">
                <i class="fa fa-phone" aria-hidden="true"></i>
                +62 895-0458-6704
            </a>
            <a href="#">
                <i class="fa fa-envelope" aria-hidden="true"></i>
                info@kuliahkaryawan.net
            </a>
        </div>
        <!--<div class="top-bar__social">-->
        <!--	<a href="#"-->
        <!--		><i class="fa fa-facebook" aria-hidden="true"></i-->
        <!--	></a>-->
        <!--	<a href="#"-->
        <!--		><i class="fa fa-twitter" aria-hidden="true"></i-->
        <!--	></a>-->
        <!--</div>-->
        <nav class="top-bar__nav collapsed" id="top-bar__nav">
            <ul class="top-bar__nav-list">
                <li><a target="_blank" href="https://pendaftaran.umiba.info/">Pendaftaran Online</a></li>
                <li><a href="#features">Biaya Kuliah</a></li>
                <!--<li><a href="https://kontak.kuliahkaryawan.net/?daftaronline.steijogja.info" target="_blank">Kontak</a></li>-->
            </ul>
        </nav>
    </div>

    <!--hero header-->
    <section class="py-5 py-md-7" id="home">
        <div class="container">
            <div class="row">
                <div class="col-md-6 my-md-auto mb-5 mb-md-0 text-center text-md-left">
                    <span class="text-uppercase text-muted small-xl">Yuk Segera Daftar !</span>
                    <h1 class="display-4 mt-2 mb-5">
                        <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?> 
                    </h1>
                    <a target="_blank" href="https://pendaftaran.umiba.info/"
                        class="btn btn-primary d-inline-flex flex-row align-items-center">
                        <em data-feather="clipboard" width="20" height="20" class="mr-2"></em>
                        Daftar Online
                    </a>
                    <!-- <a
              href="#"
              class="btn btn-secondary d-md-inline-flex flex-row align-items-center d-none show-video"
            >
              <em data-feather="play" width="20" height="20" class="mr-2"></em>
              Watch video
            </a> -->
                </div>
                <div class="col-md-6 play-wrapper">
                    <img src="https://umiba.info/images/logo/logo2.png"
                        width="500px" class="img-fluid d-block mx-auto" alt="stei jogja" />

                    <!-- <div class="play d-flex flex-row align-item-center show-video">
              <em class="icon" data-feather="play"></em>
            </div> -->
                </div>
            </div>
        </div>
    </section>

    <!-- features section -->
    <section class="py-6" id="features">
        <div class="container">
            <div class="row">
                <div class="col-md-10 mx-auto">
                    <h2 class="dot-circle">
                        Info Biaya Kuliah dan Jadwal Kuliah Kampus <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?>
                    </h2>
                    <div class="row mt-6">
                            <?php foreach ($groups as $group): ?>
    <?php
        $formulir_key = $kategori_to_formulir[$group['kategori']] ?? '';
        $biaya_formulir = $formulir[$formulir_key] ?? 'Rp 200.000';
    ?>
                        <div class="col-sm-6 mb-5">
                            <div class="media">
                                <div class="icon-box mt-0 ml-0">
                                    <div class="icon-box-inner small-xs text-primary">
                                        <span data-feather="dollar-sign" width="30" height="30"></span>
                                    </div>
                                </div>
                                <div class="media-body">
                                    <h5 class="mt-0"><?= implode(', ', $group['jurusan']) ?></h5>
                                    <span class=""><b>Kelas Karyawan</b><br />
                                        Biaya Formulir = <?= $biaya_formulir ?>,-<br />
                                        Biaya Awal Rp. <?= number_format($group['biaya_awal'], 0, ',', '.') ?>,- (Angs 1 UKT+ Biaya Almamater + KTM + PKKMB)<br />
                                        Biaya Kuliah Cukup Rp <?= number_format($group['biaya_spp'], 0, ',', '.') ?>/Bulan flat sampai
                                        lulus</span>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>

                        
                        
                        <!-- <div class="col-sm-6 mb-5">
                <div class="media">
                  <div class="icon-box mt-0 ml-0">
                    <div class="icon-box-inner small-xs text-primary">
                      <span
                        data-feather="droplet"
                        width="30"
                        height="30"
                      ></span>
                    </div>
                  </div>
                  <div class="media-body">
                    <h5 class="mt-0">Color schemes</h5>
                    <span class="text-muted"
                      >Nam liber tempor cum soluta nobis eleifend option congue
                      nihil imper per tem por legere me doming.</span
                    >
                  </div>
                </div>
              </div> -->
                        <!-- <div class="col-sm-6 mb-5">
                <div class="media">
                  <div class="icon-box mt-0 ml-0">
                    <div class="icon-box-inner small-xs text-primary">
                      <span
                        data-feather="headphones"
                        width="30"
                        height="30"
                      ></span>
                    </div>
                  </div>
                  <div class="media-body">
                    <h5 class="mt-0">24/7 supports</h5>
                    <span class="text-muted"
                      >Nam liber tempor cum soluta nobis eleifend option congue
                      nihil imper per tem por legere me doming.</span
                    >
                  </div>
                </div>
              </div> -->
                    </div>
                </div>
            </div>
            <div class="row mt-4">
                <div class="col-md-6 mx-auto text-center">
                    <h5 class="mb-4">Info Lebih Lanjut</h5>
                    <a href="https://api.whatsapp.com/send?phone=6287890198284&text=Hallo%20Admin%20UMIBA%20Saya%20Mau%20Bertanya%20%3F%0ASumber%20%3A%20daftaronline.umiba.info" target="_blank" class="btn btn-primary page-scroll">Contact us</a>
                </div>
            </div>
        </div>
    </section>

    <!--pricing section-->
    <section class="pt-6" id="pricing">
        <div class="container">
            <div class="row">
                <div class="col-md-10 mx-auto">
                    <h2 class="dot-circle">Masih bingung cari kuliah di Bandung? Yuk Gabung kampus <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?> di Bandung 
                    </h2>
                    <p class="text-muted lead">Yuk simak penjelasan berikut ini !</p>
                    <div class="row pricing-table mt-5">
                        <div class="col-sm-8">
                            <ul class="list-unstyled pricing-list">
                                <li>
                                    <h5>Daftar Kuliah Sangat Mudah</h5>
                                    <hr />
                                    <p class="text-justify">
                                        <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?> merupakan salah satu
                                        perguruan tinggi swasta yang terletak di Jakarta. Dengan
                                        Prodi S1 Hukum, S1 Aktuaria, S1 Ilmu Komputer, S1 Sistem dan Teknologi Informasi, S1 Manajemen, S2 Manajemen	
                                        yang terakreditasi  biaya kuliah cicilan bulanan sangat membantu bagi masyarakat
                                        yang ingin mendaftar kuliah untuk jenjang karir yang lebih baik.
                                        <a href="https://pendaftaran.umiba.info/" target="_blank" style="color: red">
                                            Pendaftaran Online</a>
                                    </p>
                                    <p>
                                        <b>Baca Juga :</b> <a href="https://umiba.info/" style="color: blue">Biaya
                                            Kuliah Kelas Karyawan Manajemen</a>
                                    </p>
                                    <br/>
                                      <h5>Bingung Kuliah dimana setelah lulus ? <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?> Solusinya !</h5>
                                    <hr />
                                    <p class="text-justify">
                                        Setelah temen-temen lulus dibangku sekolah, pastinya temen-temen pengen kuliah kan ? untuk menambah ilmu pengetahuan temen2, entah ingin berkarir dengan lebih baik lagi bukan ? jika temen2 ingin kuliah dengan waktu yang flexsibel temen2 tepat banget mengunjungi website ini, karena temen2 bakalan dikenalkan dengan kampus kuliah karyawan k2, dimana k2 mempunyai kampus yang berkualitas yaitu ada kampus <?= !empty($namaKampus) ? htmlspecialchars($namaKampus) : 'Data tidak tersedia' ?> yang pastinya terakreditasi 
                                    </p>
                                    <p>
                                        <b>Baca Juga :</b> <a href="https://umiba.info/" style="color: blue">Biaya
                                            Kuliah Kelas Karyawan Ciputat</a>
                                    </p>
                                    <p>
                                        <b>Baca Juga :</b> <a href="https://stesbn.info/" style="color: blue">Kampus
                                            dengan jurusan Perbankan Syariah</a>
                                    </p>
                                </li>
                                <!-- <li>
                    <h5>Biaya Kuliah Paket Bulanan Tanpa Biaya Lain</h5>
                    <p class="text-muted">
                      Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    </p>
                  </li> -->
                                <!-- <li>
                    <h5>
                      Semester 6 Akan Gathering ke Wisata Wisata terdekat antara
                      mahasiswa dan Manajemen (K2)
                    </h5>
                    <p class="text-muted">
                      Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    </p>
                  </li> -->
                                <!-- <li>
                    <h5>Pembayaran Terekap/Tersimpan di Sistem</h5>
                    <p class="text-muted">
                      Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                    </p>
                  </li> -->
                            </ul>
                        </div>
                        <div class="col-md-4 play-wrapper">
                            <img src="https://kuliahkaryawan.net/assets/images/k2-final-logo.png" width="200px" class="img-fluid d-block mx-auto"
                                alt="kuliahkaryawan" />

                            <!-- <div class="play d-flex flex-row align-item-center show-video">
              <em class="icon" data-feather="play"></em>
            </div> -->
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <!--help section-->
    <!-- <section class="mt-7" id="contact">
      <div class="container">
        <div class="row">
          <div class="col-md-10 mx-auto">
            <h2 class="dot-circle">Need help?</h2>
            <p class="text-muted lead">We'd love to answer your questions.</p>
            <div class="row mt-5 card-contacts">
              <div class="col-md-6 mb-3">
                <div class="card">
                  <div class="card-body text-center">
                    <div class="icon-box">
                      <div class="icon-box-inner small-xs text-primary">
                        <span
                          data-feather="inbox"
                          width="30"
                          height="30"
                        ></span>
                      </div>
                    </div>
                    <h5>Send us an email</h5>
                    <p class="text-muted small-xl">
                      We usually reply within 24 hours.
                    </p>
                  </div>
                </div>
              </div>
              <div class="col-md-6 mb-3">
                <div class="card">
                  <div class="card-body text-center">
                    <div class="icon-box">
                      <div class="icon-box-inner small-xs text-primary">
                        <span
                          data-feather="message-circle"
                          width="30"
                          height="30"
                        ></span>
                      </div>
                    </div>
                    <h5>Chat with us</h5>
                    <p class="text-muted small-xl">
                      The fastest way to contact us.
                    </p>
                  </div>
                </div>
              </div>
            </div>
            <div class="row mt-5">
              <div class="col-md-6 mb-5">
                <h6>Can I try Snap for free?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
              <div class="col-md-6 mb-5">
                <h6>Do you have hidden fees?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
              <div class="col-md-6 mb-5">
                <h6>What are the payment methods you accept?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
              <div class="col-md-6 mb-5">
                <h6>How often do you release updates?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
              <div class="col-md-6 mb-5">
                <h6>What is your refund policy?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
              <div class="col-md-6 mb-5">
                <h6>How can I contact you?</h6>
                <p class="text-muted">
                  Nam liber tempor cum soluta nobis eleifend option congue nihil
                  imper per tem por legere me doming.
                </p>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section> -->

    <!--footer / contact-->
    <footer class="mt-5 mb-4">
        <div class="container">
            <div class="row">
                <div class="col-md-4 my-auto text-center text-md-left">
                    &copy;2022 Edukasi Indonesia Jaya (Edunesia).
                </div>
                <div class="col-md-4 text-center">
                    <ul class="list-inline social social-white-alt social-rounded social-sm mb-0">
                        <li class="list-inline-item">
                            <a href="<?= htmlspecialchars($sosmedLinks['facebook'] ?? '#') ?>"><i class="fa fa-facebook"></i></a>
                        </li>
                        <li class="list-inline-item">
                            <a href=""><i class="fa fa-twitter"></i></a>
                        </li>
                        <li class="list-inline-item">
                            <a href="<?= htmlspecialchars($sosmedLinks['instagram'] ?? '#') ?>"><i class="fa fa-instagram"></i></a>
                        </li>
                    </ul>
                </div>
                <div class="col-md-3 text-center text-md-right mb-0">
                    <ul class="list-inline">
                        <li class="list-inline-item"><a href="#">Privacy</a></li>
                        <li class="list-inline-item"><a href="#">Terms</a></li>
                    </ul>
                </div>
            </div>
            <div class="row mt-4">
                <div class="col-12 text-muted text-center small">
                    &copy; 2022 Edukasi Indonesia Jaya (Edunesia) - All Rights Reserved
                </div>
            </div>
        </div>
    </footer>

    <!--video section-->
    <section class="video-wrapper">
        <div class="video-close" id="video-close">
            <em data-feather="x" class="icon"></em>
        </div>
        <div class="container">
            <div class="row">
                <div class="col-md-8 mx-auto my-auto">
                    <div class="embed-responsive embed-responsive-16by9">
                        <iframe class="embed-responsive-item allowfullscreen"
                            src="https://www.youtube.com/embed/MGsalg2f9js?rel=0&amp;controls=0&amp;showinfo=0"
                            allowfullscreen="" frameborder="0" height="415" width="100%">
                        </iframe>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <!--scroll to top-->
    <div class="scroll-top">
        <i class="fa fa-angle-up" aria-hidden="true"></i>
    </div>

    <!-- theme switcher (FOR DEMO ONLY - REMOVE FROM PRODUCTION)-->
    <!--<div class="switcher-wrap">-->
    <!--  <div class="switcher-trigger">-->
    <!--    <span class="fa fa-gear"></span>-->
    <!--  </div>-->
    <!--  <div class="color-switcher">-->
    <!--    <h6>Color Switcher</h6>-->
    <!--    <ul class="mt-3 clearfix">-->
    <!--      <li-->
    <!--        class="bg-cyan active"-->
    <!--        data-color="default"-->
    <!--        title="Default Cyan"-->
    <!--      ></li>-->
    <!--      <li class="bg-orange" data-color="orange" title="Orange"></li>-->
    <!--      <li class="bg-blue" data-color="blue" title="Blue"></li>-->
    <!--      <li class="bg-red" data-color="red" title="Red"></li>-->
    <!--      <li class="bg-indigo" data-color="indigo" title="Indigo"></li>-->
    <!--      <li class="bg-green" data-color="green" title="Green"></li>-->
    <!--      <li class="bg-black" data-color="black" title="Black"></li>-->
    <!--      <li class="bg-teal" data-color="teal" title="Teal"></li>-->
    <!--      <li class="bg-purple" data-color="purple" title="Purple"></li>-->
    <!--      <li class="bg-pink" data-color="pink" title="Pink"></li>-->
    <!--    </ul>-->
    <!--  </div>-->
    <!--</div>-->

    <!-- jQuery first, then Popper.js, then Bootstrap JS -->


    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js"></script>
    <script src="js/scripts.js"></script>
    <script src="js/navbar.js"></script>
    <script>
        (function () {
            if (document.querySelector("#top-nav-toggle")) {
                var navToggle = document.querySelector("#top-nav-toggle");

                function watchNavClose(e) {
                    var topNav = document.querySelector(".top-bar");
                    if (!e.path.includes(topNav)) {
                        openCloseNav();
                        document.documentElement.removeEventListener("click", watchNavClose);
                    }
                }

                function openCloseNav() {
                    var navToggle = document.querySelector("#top-nav-toggle");

                    if (!navToggle.classList.contains("closed")) {
                        navToggle.classList.add("closed");
                        document.querySelector("#top-bar__nav").classList.remove("collapsed");
                        document.querySelector("html").addEventListener("click", watchNavClose);
                    } else {
                        navToggle.classList.remove("closed");
                        document.querySelector("#top-bar__nav").classList.add("collapsed");
                        document.documentElement.removeEventListener("click", watchNavClose);
                    }
                }

                navToggle.addEventListener("click", openCloseNav);
            }
        })();
    </script>
    <!-- Function used to shrink nav bar removing paddings and adding black background -->
    <script>
        $(window).scroll(function () {
            if ($(document).scrollTop() > 50) {
                $(".nav").addClass("affix");
                console.log("OK");
            } else {
                $(".nav").removeClass("affix");
            }
        });
    </script>
    <script src="https://code.jquery.com/jquery-3.2.1.min.js"></script>
    <script src="https://code.jquery.com/jquery-1.6.4.js"></script>
    	<script>
          $.getJSON('https://kuliahkaryawan.net/api/BiayaSTEI JOGJA/1', function(data){
           
	     	let biayaDaftarS1 = `${data.biaya_daftar_s1}`
           	$(".biayaDaftarS1").html(biayaDaftarS1);
           	
		let biayaDaftarS2 = `${data.biaya_daftar_s2}`
           	$(".biayaDaftarS2").html(biayaDaftarS2);

		let biayaAwalS1KR = `${data.biaya_awal_s1_kr}`
           	$(".biayaAwalS1KR").html(biayaAwalS1KR);
           	
		let biayaAwalS1KK = `${data.biaya_awal_s1_kk}`
           	$(".biayaAwalS1KK").html(biayaAwalS1KK);

		let biayaAwalS2 = `${data.biaya_awal_s2}`
           	$(".biayaAwalS2").html(biayaAwalS2);
           	
		let biayaBulananS1KR = `${data.biaya_bulanan_s1_kr}`
           	$(".biayaBulananS1KR").html(biayaBulananS1KR);

		let biayaBulananS1IPL = `${data.biaya_bulanan_s1_kk_ipl}`
           	$(".biayaBulananS1IPL").html(biayaBulananS1IPL);
           	
		let biayaBulananS1IPM = `${data.biaya_bulanan_s1_kk_ipm}`
           	$(".biayaBulananS1IPM").html(biayaBulananS1IPM);

		let biayaBulananS2 = `${data.biaya_bulanan_s2}`
           	$(".biayaBulananS2").html(biayaBulananS2);
           	
		let biayaJaketS2 = `${data.biaya_jaket_s2}`
           	$(".biayaJaketS2").html(biayaJaketS2);
          });
     </script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/popper.js/1.12.9/umd/popper.min.js"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/feather-icons/4.5.0/feather.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.min.js"></script>
    <script src="js/scripts.js"></script>
    <script src="js/navbar.js"></script>
</body>

</html>